# AWS::IoTEvents Construct Library



AWS IoT Events enables you to monitor your equipment or device fleets for
failures or changes in operation, and to trigger actions when such events
occur. 

## Installation

Install the module:

```console
$ npm i @aws-cdk/aws-iotevents
```

Import it into your code:

```ts nofixture
import * as iotevents from 'monocdk/aws-iotevents';
```

## `DetectorModel`

The following example creates an AWS IoT Events detector model to your stack.
The detector model need a reference to at least one AWS IoT Events input.
AWS IoT Events inputs enable the detector to get MQTT payload values from IoT Core rules.

```ts
import * as iotevents from 'monocdk/aws-iotevents';

const input = new iotevents.Input(this, 'MyInput', {
  inputName: 'my_input', // optional
  attributeJsonPaths: ['payload.temperature'],
});

const onlineState = new iotevents.State({
  stateName: 'online',
  onEnter: [{
    eventName: 'test-event',
    condition: iotevents.Expression.currentInput(input),
  }],
});

new iotevents.DetectorModel(this, 'MyDetectorModel', {
  detectorModelName: 'test-detector-model', // optional
  initialState: onlineState,
});
```
